@@ -21,6 +21,8 @@ class GetInfo:
         if isinstance(object_guid, str):
             if object_guid.startswith('c0'):
                 return await self.get_channel_info(object_guid)
+            elif object_guid.startswith('b0'):
+                return await self.get_bot_info(object_guid)
             elif object_guid.startswith('u0'):
                 return await self.get_user_info(object_guid)
             elif object_guid.startswith('g0'):
