@@ -22,6 +22,7 @@ class SendDocument:
         caption: Optional[str] = None,
         reply_to_message_id: Optional[str] = None,
         auto_delete: Optional[int] = None,
+        progress: bool = False,
         *args, **kwargs,
     ) -> rubigram.types.Update:
         """
@@ -33,6 +34,8 @@ class SendDocument:
         - caption (Optional[str]): The caption for the document. Defaults to None.
         - reply_to_message_id (Optional[str]): The ID of the message to which this is a reply. Defaults to None.
         - auto_delete (Optional[int]): Auto-delete duration in seconds. Defaults to None.
+        - progress: Optional message object for showing upload progress.
+                    If None, only terminal progress will be shown.
 
         Returns:
         - rubigram.types.Update: The update indicating the success of the document sending.
@@ -44,6 +47,7 @@ class SendDocument:
             file_inline=document,
             thumb=False,
             auto_delete=auto_delete,
+            progress=progress,
             *args,
             **kwargs,
         )
